@@ -6,11 +6,11 @@ class DenominatorNotFoundError(Exception):
     pass
 
 
-class ExtraLeftOrMissingRight(Exception):
+class ExtraLeftOrMissingRightError(Exception):
     pass
 
 
-class MissingSuperScriptOrSubscript(Exception):
+class MissingSuperScriptOrSubscriptError(Exception):
     pass
 
 
@@ -20,3 +20,7 @@ class DoubleSubscriptsError(Exception):
 
 class DoubleSuperscriptsError(Exception):
     pass
+
+
+class NoAvailableTokensError(Exception):
+    pass
