@@ -30,4 +30,12 @@ def parse_symbols() -> dict:
                 for equivalent in re.findall(r"=\s+(\\[^,^ ]+),?", columns[-1]):
                     if equivalent not in _symbols:
                         _symbols[equivalent] = _unicode
+    _symbols.update(
+        {
+            r"\bigcirc": _symbols[r"\lgwhtcircle"],
+            r"\Box": _symbols[r"\square"],
+            r"\centerdot": _symbols[r"\cdot"],
+            r"\circledS": "024C8",
+        }
+    )
     return _symbols
